@@ -24,6 +24,7 @@
 #ifndef __CONFIGADV_H
 #define __CONFIGADV_H
 
+#include <GAMEDEF.h>
 #include <stdint.h>
 
 class ConfigAdv
@@ -58,6 +59,10 @@ public:
 	int			nation_start_god_level;
 	int			nation_start_tech_inc_all_level;
 
+	// race settings
+	char			race_random_list[MAX_RACE];
+	int			race_random_list_max;
+
 	// remote settings
 	char		        remote_compare_object_crc;
 	char			remote_compare_random_seed;
@@ -70,9 +75,13 @@ public:
 	int			town_ai_emerge_town_pop_limit;
 	char			town_loyalty_qol;
 
+	// unit settings
+	char			unit_loyalty_require_local_leader;
+
 	// vga settings
 	char			vga_allow_highdpi;
 	char			vga_full_screen;
+	char			vga_full_screen_desktop;
 	char			vga_keep_aspect_ratio;
 	char			vga_pause_on_focus_loss;
 
