@@ -77,7 +77,7 @@ public:
 	void 		init_derived();
 
 	void 		put_info(int);
-	void 		detect_info();
+	int		detect_info();
 	void		put_det(int);
 
 	void		next_day();
