@@ -332,7 +332,7 @@ int Button3D::detect(unsigned keyCode1, unsigned keyCode2, int detectRight, int
 			rc = 2;
 	}
 
-	else if( mouse.key_code )
+	else if( mouse.unique_key_code )
 	{
 		unsigned mouseKey=mouse.unique_key_code;
 
