@@ -423,7 +423,7 @@ int Button::detect(unsigned keyCode1, unsigned keyCode2, int detectRight, int su
 		else
 			rc = 2;
 	}
-	else if( mouse.key_code )
+	else if( mouse.unique_key_code )
 	{
 		unsigned mouseKey=mouse.unique_key_code;
 
