@@ -72,6 +72,7 @@
 // ##### begin Gilbert 2/10 #######//
 #include <OFIRMDIE.h>
 // ##### end Gilbert 2/10 #######//
+#include <ConfigAdv.h>
 
 //---------------- DETECT_SPREAD ----------------//
 //
@@ -173,6 +174,16 @@ int Game::init(int loadGameCall)
 	tornado_array.init();
 	war_point_array.init();
 
+	if( config_adv.big_dynarray_mode )
+	{
+		firm_array.resize(5000);
+		town_array.resize(5000);
+		unit_array.resize(5000);
+		bullet_array.resize(5000);
+		rebel_array.resize(5000);
+		spy_array.resize(5000);
+	}
+
    //------ init game surface class ----------//
 
 	power.init();
