@@ -101,11 +101,6 @@ void Sys::detect()
 		return;
 	}
 
-	if( VBrowse::press_record )		// if the user is pulling the records of the browser up and down, calling detect() routines of other controls will confuse it
-	{
-		VBrowse::press_vbrowse_ptr->detect();
-	}
-
 	if( mouse.is_key_event() )
 	{
 		process_key(mouse.scan_code, mouse.event_skey_state);
