@@ -196,6 +196,9 @@ void Unit::detect_info()
 			detect_build_menu();
 			break;
 	}
+
+	if( detect_select_hotkey() )
+		return;
 }
 //----------- End of function Unit::detect_info -----------//
 
@@ -1023,17 +1026,20 @@ void Unit::disp_build(int refreshFlag)
 {
 	if( refreshFlag == INFO_REPAINT )
 	{
-		vga_util.d3_panel_up( INFO_X1, INFO_Y1, INFO_X2, INFO_Y1+42 );
 
 		String str;
 
 		str = _(select_where_to_build[power.command_para-1]);
 
-// FRENCH
-//		font_san.put_paragraph( INFO_X1, INFO_Y1, INFO_X2, INFO_Y2, str, 0 );
+		int dispLines, totalLines;
+		font_san.count_line( INFO_X1+7, INFO_Y1+5, INFO_X2-7, INFO_Y2-5, str, 0, dispLines, totalLines );
+		int textHeight = font_san.text_height()*dispLines+14;
+
+		vga_util.d3_panel_up( INFO_X1, INFO_Y1, INFO_X2, INFO_Y1+textHeight );
+
 		font_san.put_paragraph( INFO_X1+7, INFO_Y1+5, INFO_X2-7, INFO_Y2-5, str );
 
-		button_cancel2.paint_text( INFO_X1, INFO_Y1+45, INFO_X2, INFO_Y1+70, _("Cancel") );
+		button_cancel2.paint_text( INFO_X1, INFO_Y1+textHeight+3, INFO_X2, INFO_Y1+textHeight+28, _("Cancel") );
 	}
 }
 //----------- End of function Unit::disp_build -----------//
@@ -1555,6 +1561,40 @@ void Unit::disp_hit_point(int dispY1)
 }
 //----------- End of function Unit::disp_hit_point -----------//
 
+
+//--------- Begin of function Unit::detect_select_hotkey ---------//
+//
+int Unit::detect_select_hotkey()
+{
+	if( ISKEY(KEYEVENT_OBJECT_PREV) )
+	{
+		unit_array.disp_next(-1, 0);    // previous same object type of any nation
+		return 1;
+	}
+
+	if( ISKEY(KEYEVENT_OBJECT_NEXT) )
+	{
+		unit_array.disp_next(1, 0);     // next same object type of any nation
+		return 1;
+	}
+
+	if( ISKEY(KEYEVENT_NATION_OBJECT_PREV) )
+	{
+		unit_array.disp_next(-1, 1);    // prevous same object type of the same nation
+		return 1;
+	}
+
+	if( ISKEY(KEYEVENT_NATION_OBJECT_NEXT) )
+	{
+		unit_array.disp_next(1, 1);     // next same object type of the same nation
+		return 1;
+	}
+
+	return 0;
+}
+//----------- End of function Unit::detect_select_hotkey -----------//
+
+
 #ifdef DEBUG
 
 //----------- Begin of static function disp_debug_info -----------//
